@@ -1,9 +1,12 @@
 from marshmallow.fields import *
 from .instance import Instance
 from .active import Active
+from .email import Email
+from .enum import Enum
+from .icontains import IContains
 
 
 __all__ = ["Field", "Raw", "Nested", "Mapping", "Dict", "List", "Tuple", "String", "UUID", "Number", "Integer",
            "Decimal", "Boolean", "Float", "DateTime", "NaiveDateTime", "AwareDateTime", "Time", "Date", "TimeDelta",
            "Url", "URL", "Email", "IP", "IPv4", "IPv6", "Method", "Function", "Str", "Bool", "Int", "Constant",
-           "Pluck", "Instance", "Active"]
+           "Pluck", "Instance", "Active", "Email", "Enum", "IContains"]
